@@ -60,7 +60,7 @@ plot.HypervolumeList <- function(x,
                                  show.random=TRUE, show.density=TRUE,show.data=TRUE,
                                  names=NULL, show.legend=TRUE, limits=NULL, 
                                  show.contour=TRUE, contour.lwd=1.5, 
-                                   contour.type='alphahull', 
+                                   contour.type='kde', 
                                    contour.alphahull.alpha=0.25,
                                    contour.ball.radius.factor=1, 
                                    contour.kde.level=0.01,
